==> citrine-0.9.5.tar.gz: citrine-0.9.5/i18n/cs/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Mapa nový) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "umístit:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " na:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Seznam nový "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Seznam ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL             "Nic"
#define CTR_DICT_BOOLEAN         "Boolean"
#define CTR_DICT_TRUE            "Pravda"
#define CTR_DICT_FALSE           "Nepravda"
#define CTR_DICT_NUMBER          "Číslo"
#define CTR_DICT_STRING          "Řetězec"
#define CTR_DICT_TASK      "Kód"
#define CTR_DICT_OBJECT          "Objekt"
#define CTR_DICT_ARRAY_OBJECT     "Seznam"
#define CTR_DICT_MAP_OBJECT      "Mapa"
#define CTR_DICT_PROGRAM       "Program"
#define CTR_DICT_FILE            "Soubor"
#define CTR_DICT_MOMENT      "Okamžik"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "⋅"
#define CTR_DICT_DIVISION   	 "∶"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW             "nový"
#define CTR_DICT_EQUALS          "rovná se:"
#define CTR_DICT_AND             "a zároveň:"
#define CTR_DICT_OR              "nebo:"
#define CTR_DICT_MODULO          "modulo:"
#define CTR_DICT_NOR             "ani:"
#define CTR_DICT_ONDO            "na:udělat:"
#define CTR_DICT_TYPE            "typ"
#define CTR_DICT_ISNIL           "Nic?"
#define CTR_DICT_MYSELF          "sám"
#define CTR_DICT_DO              "udělat"
#define CTR_DICT_DONE            "hotovo"
#define CTR_DICT_IFFALSE         "nepravda:"
#define CTR_DICT_IFTRUE          "pravda:"
#define CTR_DICT_WHILE           "zatímco:"
#define CTR_DICT_MESSAGEARGS     "zpráva:parametry:"
#define CTR_DICT_MESSAGE         "zpráva:"
#define CTR_DICT_LEARN           "naučit:znamená:"
#define CTR_DICT_BREAK           "přestat"
#define CTR_DICT_CONTINUE        "pokračovat"
#define CTR_DICT_ELSE            "jinak:"
#define CTR_DICT_NOT             "nikoliv"
#define CTR_DICT_TONUMBER        "číslo"
#define CTR_DICT_ITONUMBER        "neformátované číslo"
#define CTR_DICT_TOSTRING        "řetězec"
#define CTR_DICT_CHAR_AT_SET     "znak:"
#define CTR_DICT_EITHEROR        "buď:nebo:"
#define CTR_DICT_BY_SET       	 "podle:"
#define CTR_DICT_FLOOR           "dolní celá část"
#define CTR_DICT_CEIL            "horní celá část"
#define CTR_DICT_ROUND           "zaokrouhlit"
#define CTR_DICT_ABS             "absolutní"
#define CTR_DICT_SQRT            "odmocnina"
#define CTR_DICT_POWER           "umocnit na:"
#define CTR_DICT_MIN             "minimum" 
#define CTR_DICT_MAX             "maximum"
#define CTR_DICT_ODD   	         "lichý?" 
#define CTR_DICT_EVEN   	     "sudý?"
#define CTR_DICT_POS   	         "kladný?" 
#define CTR_DICT_NEG   	         "záporný?" 
#define CTR_DICT_TOBOOL          "boolean" 
#define CTR_DICT_RANDOM_NUM_BETWEEN         "mezi:a hodnotou:" 
#define CTR_DICT_LENGTH	         "délka" 
#define CTR_DICT_FROM_LENGTH	 "od:délka:" 
#define CTR_DICT_TRIM	         "odstranit okolní mezery" 
#define CTR_DICT_AT              "na:"
#define CTR_DICT_POSITION_SET    "pozice:" 
#define CTR_DICT_INDEX_OF        "hledat:" 
#define CTR_DICT_LAST_INDEX_OF	 "poslední:" 
#define CTR_DICT_REPLACE_WITH	 "nahradit:za:" 
#define CTR_DICT_SPLIT	         "rozdělit:"
#define CTR_DICT_SKIP            "přeskočit:" 
#define CTR_DICT_RUN             "spustit" 
#define CTR_DICT_APPLY_TO        "aplikovat:" 
#define CTR_DICT_APPLY_TO_AND    "aplikovat:a také:" 
#define CTR_DICT_VALUE_SET       "nastavit:na:" 
#define CTR_DICT_ERROR	         "chyba:" 
#define CTR_DICT_CATCH           "chytit:" 
#define CTR_DICT_PUSH_SYMBOL     ";" 
#define CTR_DICT_SHIFT           "vysunout začátek" 
#define CTR_DICT_COUNT           "počet" 
#define CTR_DICT_JOIN            "spojit:" 
#define CTR_DICT_POP             "vysunout konec" 
#define CTR_DICT_SORT            "seřadit:" 
#define CTR_DICT_PUT_AT          "umístit:na:" 
#define CTR_DICT_MAP             "všem:" 
#define CTR_DICT_EACH            "každý:"
#define CTR_DICT_WRITE           "psát:"
#define CTR_DICT_PATH            "cesta"
#define CTR_DICT_READ            "číst"
#define CTR_DICT_APPEND          "připojit:"
#define CTR_DICT_PREPEND         "předřadit:"
#define CTR_DICT_EXISTS          "existuje"
#define CTR_DICT_SIZE            "velikost"
#define CTR_DICT_DELETE          "smazat"
#define CTR_DICT_USE_SET         "použít:"
#define CTR_DICT_ARRAY            "seznam:"
#define CTR_DICT_END             "na konec"
#define CTR_DICT_ARGUMENT	     "parametr:" 
#define CTR_DICT_ARGUMENT_COUNT	 "parametrů" 
#define CTR_DICT_WAIT_FOR_PASSW	 "zeptat se na heslo"
#define CTR_DICT_WAIT_FOR_INPUT	 "zeptat se" 
#define CTR_DICT_INPUT           "vstup" 
#define CTR_DICT_FLUSH           "vyprázdnit"
#define CTR_DICT_WAIT            "počkat:" 
#define CTR_DICT_TIME	         "čas" 
#define CTR_DICT_RESPOND_TO      "odpovědět:" 
#define CTR_DICT_RESPOND_TO_AND  "odpovědět:a také:" 
#define CTR_DICT_SHELL           "rozhraní:"
#define CTR_DICT_SWEEP           "vymazat paměť" 
#define CTR_DICT_MEMORY_LIMIT	 "paměť:"
#define CTR_DICT_MEMORY          "paměť"
#define CTR_DICT_GC_MODE            "pořádnost:" 
#define CTR_DICT_HASH_WITH_KEY   "heš:"
#define CTR_DICT_CHARACTERS      "znaky"
#define CTR_DICT_QUALIFIER_SET         "jednotka:"
#define CTR_DICT_QUALIFIER   "jednotka"
#define CTR_DICT_NEW_SET         "nový:"
#define CTR_DICT_HOUR            "hodina"
#define CTR_DICT_HOUR_SET        "hodina:"
#define CTR_DICT_MINUTE_SET      "minuta:"
#define CTR_DICT_MINUTE          "minuta"
#define CTR_DICT_SECOND_SET      "vteřina:"
#define CTR_DICT_SECOND          "vteřina"
#define CTR_DICT_DAY             "den"
#define CTR_DICT_DAY_SET         "den:"
#define CTR_DICT_WEEK            "týden"
#define CTR_DICT_WEEK_SET        "týden:"
#define CTR_DICT_MONTH           "měsíc"
#define CTR_DICT_MONTH_SET       "měsíc:"
#define CTR_DICT_YEAR            "rok"
#define CTR_DICT_RAW              "surový"
#define CTR_DICT_YEAR_SET        "rok:"
#define CTR_DICT_WEEK_DAY        "den v týdnu"
#define CTR_DICT_YEAR_DAY        "den v roce"
#define CTR_DICT_ZONE            "pásmo"
#define CTR_DICT_ZONE_SET        "pásmo:"
#define CTR_DICT_ADD_SET         "přičíst:"
#define CTR_DICT_SUBTRACT_SET    "odečíst:"
#define CTR_DICT_MULTIPLIER_SET  "vynásobit:"
#define CTR_DICT_DIVIDER_SET     "vydělit:"
#define CTR_DICT_LAST            "poslední"
#define CTR_DICT_FIRST           "první"
#define CTR_DICT_SECOND_LAST     "druhý od konce"
#define CTR_DICT_FILL_WITH       "naplnit:čím:"
#define CTR_DICT_SPLICE          "nahradit:délka:za:"
#define CTR_DICT_VALUES          "hodnoty"
#define CTR_DICT_ENTRIES         "záznamy"
#define CTR_DICT_COMPARE_SET     "porovnat:"
#define CTR_DICT_HAS             "má:"
#define CTR_DICT_COPY            "kopie"
#define CTR_DICT_CASE_DO         "v případě:udělat:"
#define CTR_DICT_STOP            "stop"
#define CTR_DICT_ASCII_UPPER_CASE                "velkými písmeny" 
#define CTR_DICT_ASCII_LOWER_CASE                "malými písmeny"
#define CTR_DICT_CONTAINS                        "obsahuje:"
#define CTR_DICT_APPLY_TO_AND_AND                "aplikovat:a také:a také:"
#define CTR_DICT_ENVIRONMENT_VARIABLE            "nastavení:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE        "nastavení:hodnota:" 
#define CTR_DICT_RESPOND_TO_AND_AND              "odpovědět:a také:a také:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND          "odpovědět:a také:a také:a také:"
#define CTR_DICT_CURRENT_TASK                      "tento blok kódu"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     " "
#define CTR_DICT_QUOT_OPEN                       "„"
#define CTR_DICT_QUOT_CLOSE                      "“"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "kód"
#define CTR_DICT_PROCEDURE                       "postup"
#define CTR_DICT_TOOBJECT                        "objekt"
#define CTR_DICT_PATH_OBJECT "Umístění souboru"
#define CTR_DICT_CMD_OBJECT  "Instrukce"
#define CTR_DICT_RECURSIVE "rekurzivní"

==> citrine-0.9.6.tar.gz: citrine-0.9.6/i18n/cs/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Mapa nový) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "umístit:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " na:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Seznam nový "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Seznam ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL             "Nic"
#define CTR_DICT_BOOLEAN         "Boolean"
#define CTR_DICT_TRUE            "Pravda"
#define CTR_DICT_FALSE           "Nepravda"
#define CTR_DICT_NUMBER          "Číslo"
#define CTR_DICT_STRING          "Řetězec"
#define CTR_DICT_TASK      "Kód"
#define CTR_DICT_OBJECT          "Objekt"
#define CTR_DICT_ARRAY_OBJECT     "Seznam"
#define CTR_DICT_MAP_OBJECT      "Mapa"
#define CTR_DICT_PROGRAM       "Program"
#define CTR_DICT_FILE            "Soubor"
#define CTR_DICT_MOMENT      "Okamžik"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "⋅"
#define CTR_DICT_DIVISION   	 "∶"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW             "nový"
#define CTR_DICT_EQUALS          "rovná se:"
#define CTR_DICT_AND             "a zároveň:"
#define CTR_DICT_OR              "nebo:"
#define CTR_DICT_MODULO          "modulo:"
#define CTR_DICT_NOR             "ani:"
#define CTR_DICT_ONDO            "na:udělat:"
#define CTR_DICT_TYPE            "typ"
#define CTR_DICT_ISNIL           "Nic?"
#define CTR_DICT_MYSELF          "sám"
#define CTR_DICT_DO              "udělat"
#define CTR_DICT_DONE            "hotovo"
#define CTR_DICT_IFFALSE         "nepravda:"
#define CTR_DICT_IFTRUE          "pravda:"
#define CTR_DICT_WHILE           "zatímco:"
#define CTR_DICT_MESSAGEARGS     "zpráva:parametry:"
#define CTR_DICT_MESSAGE         "zpráva:"
#define CTR_DICT_LEARN           "naučit:znamená:"
#define CTR_DICT_BREAK           "přestat"
#define CTR_DICT_CONTINUE        "pokračovat"
#define CTR_DICT_ELSE            "jinak:"
#define CTR_DICT_NOT             "nikoliv"
#define CTR_DICT_TONUMBER        "číslo"
#define CTR_DICT_ITONUMBER        "neformátované číslo"
#define CTR_DICT_TOSTRING        "řetězec"
#define CTR_DICT_CHAR_AT_SET     "znak:"
#define CTR_DICT_EITHEROR        "buď:nebo:"
#define CTR_DICT_BY_SET       	 "podle:"
#define CTR_DICT_FLOOR           "dolní celá část"
#define CTR_DICT_CEIL            "horní celá část"
#define CTR_DICT_ROUND           "zaokrouhlit"
#define CTR_DICT_ABS             "absolutní"
#define CTR_DICT_SQRT            "odmocnina"
#define CTR_DICT_POWER           "umocnit na:"
#define CTR_DICT_MIN             "minimum" 
#define CTR_DICT_MAX             "maximum"
#define CTR_DICT_ODD   	         "lichý?" 
#define CTR_DICT_EVEN   	     "sudý?"
#define CTR_DICT_POS   	         "kladný?" 
#define CTR_DICT_NEG   	         "záporný?" 
#define CTR_DICT_TOBOOL          "boolean" 
#define CTR_DICT_RANDOM_NUM_BETWEEN         "mezi:a:" 
#define CTR_DICT_LENGTH	         "délka" 
#define CTR_DICT_FROM_LENGTH	 "od:délka:" 
#define CTR_DICT_TRIM	         "odstranit okolní mezery" 
#define CTR_DICT_AT              "na:"
#define CTR_DICT_POSITION_SET    "pozice:" 
#define CTR_DICT_INDEX_OF        "hledat:" 
#define CTR_DICT_LAST_INDEX_OF	 "poslední:" 
#define CTR_DICT_REPLACE_WITH	 "nahradit:za:" 
#define CTR_DICT_SPLIT	         "rozdělit:"
#define CTR_DICT_SKIP            "přeskočit:" 
#define CTR_DICT_RUN             "start" 
#define CTR_DICT_APPLY_TO        "aplikovat:" 
#define CTR_DICT_APPLY_TO_AND    "aplikovat:a také:" 
#define CTR_DICT_VALUE_SET       "nastavit:na:" 
#define CTR_DICT_ERROR	         "chyba:" 
#define CTR_DICT_CATCH           "chytit:" 
#define CTR_DICT_PUSH_SYMBOL     ";" 
#define CTR_DICT_SHIFT           "vysunout začátek" 
#define CTR_DICT_COUNT           "počet" 
#define CTR_DICT_JOIN            "spojit:" 
#define CTR_DICT_POP             "vysunout konec" 
#define CTR_DICT_SORT            "seřadit:" 
#define CTR_DICT_PUT_AT          "umístit:na:" 
#define CTR_DICT_MAP             "všem:" 
#define CTR_DICT_EACH            "každý:"
#define CTR_DICT_WRITE           "psát:"
#define CTR_DICT_PATH            "cesta"
#define CTR_DICT_READ            "číst"
#define CTR_DICT_APPEND          "připojit:"
#define CTR_DICT_PREPEND         "předřadit:"
#define CTR_DICT_EXISTS          "existuje"
#define CTR_DICT_SIZE            "velikost"
#define CTR_DICT_DELETE          "smazat"
#define CTR_DICT_USE_SET         "použít:"
#define CTR_DICT_ARRAY            "seznam:"
#define CTR_DICT_END             "konec"
#define CTR_DICT_ARGUMENT	     "parametr:" 
#define CTR_DICT_ARGUMENT_COUNT	 "parametrů" 
#define CTR_DICT_WAIT_FOR_PASSW	 "zeptat se na heslo"
#define CTR_DICT_WAIT_FOR_INPUT	 "zeptat se" 
#define CTR_DICT_INPUT           "vstup" 
#define CTR_DICT_FLUSH           "vyprázdnit"
#define CTR_DICT_WAIT            "počkat:" 
#define CTR_DICT_TIME	         "čas" 
#define CTR_DICT_RESPOND_TO      "odpovědět:" 
#define CTR_DICT_RESPOND_TO_AND  "odpovědět:a také:" 
#define CTR_DICT_SHELL           "rozhraní:"
#define CTR_DICT_SWEEP           "vymazat paměť" 
#define CTR_DICT_MEMORY_LIMIT	 "paměť:"
#define CTR_DICT_MEMORY          "paměť"
#define CTR_DICT_GC_MODE            "pořádnost:" 
#define CTR_DICT_HASH_WITH_KEY   "heš:"
#define CTR_DICT_CHARACTERS      "znaky"
#define CTR_DICT_QUALIFIER_SET         "jednotka:"
#define CTR_DICT_QUALIFIER   "jednotka"
#define CTR_DICT_NEW_SET         "nový:"
#define CTR_DICT_HOUR            "hodina"
#define CTR_DICT_HOUR_SET        "hodina:"
#define CTR_DICT_MINUTE_SET      "minuta:"
#define CTR_DICT_MINUTE          "minuta"
#define CTR_DICT_SECOND_SET      "vteřina:"
#define CTR_DICT_SECOND          "vteřina"
#define CTR_DICT_DAY             "den"
#define CTR_DICT_DAY_SET         "den:"
#define CTR_DICT_WEEK            "týden"
#define CTR_DICT_WEEK_SET        "týden:"
#define CTR_DICT_MONTH           "měsíc"
#define CTR_DICT_MONTH_SET       "měsíc:"
#define CTR_DICT_YEAR            "rok"
#define CTR_DICT_RAW              "surový"
#define CTR_DICT_YEAR_SET        "rok:"
#define CTR_DICT_WEEK_DAY        "den v týdnu"
#define CTR_DICT_YEAR_DAY        "den v roce"
#define CTR_DICT_ZONE            "pásmo"
#define CTR_DICT_ZONE_SET        "pásmo:"
#define CTR_DICT_ADD_SET         "přičíst:"
#define CTR_DICT_SUBTRACT_SET    "odečíst:"
#define CTR_DICT_MULTIPLIER_SET  "vynásobit:"
#define CTR_DICT_DIVIDER_SET     "vydělit:"
#define CTR_DICT_LAST            "poslední"
#define CTR_DICT_FIRST           "první"
#define CTR_DICT_SECOND_LAST     "druhý od konce"
#define CTR_DICT_FILL_WITH       "naplnit:čím:"
#define CTR_DICT_SPLICE          "nahradit:délka:za:"
#define CTR_DICT_VALUES          "hodnoty"
#define CTR_DICT_ENTRIES         "záznamy"
#define CTR_DICT_COMPARE_SET     "porovnat:"
#define CTR_DICT_HAS             "má:"
#define CTR_DICT_COPY            "kopie"
#define CTR_DICT_CASE_DO         "v případě:udělat:"
#define CTR_DICT_STOP            "stop"
#define CTR_DICT_ASCII_UPPER_CASE                "velkými písmeny" 
#define CTR_DICT_ASCII_LOWER_CASE                "malými písmeny"
#define CTR_DICT_CONTAINS                        "obsahuje:"
#define CTR_DICT_APPLY_TO_AND_AND                "aplikovat:a také:a také:"
#define CTR_DICT_ENVIRONMENT_VARIABLE            "nastavení:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE        "nastavení:hodnota:" 
#define CTR_DICT_RESPOND_TO_AND_AND              "odpovědět:a také:a také:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND          "odpovědět:a také:a také:a také:"
#define CTR_DICT_CURRENT_TASK                      "tento blok kódu"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     " "
#define CTR_DICT_QUOT_OPEN                       "„"
#define CTR_DICT_QUOT_CLOSE                      "“"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "kód"
#define CTR_DICT_PROCEDURE                       "postup"
#define CTR_DICT_TOOBJECT                        "objekt"
#define CTR_DICT_PATH_OBJECT "Umístění souboru"
#define CTR_DICT_CMD_OBJECT  "Instrukce"
#define CTR_DICT_RECURSIVE "rekurzivní"
